﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Xml.Linq;

using DevExpress.XtraEditors;
using DevExpress.XtraMap;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 빙맵 키
        /// </summary>
        private string bingKey = "INPUT YOUR BING KEY";

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load += Form_Load;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            #region 빙 맵 데이터 공급자를 설정한다.

            this.bingMapDataProvider.BingKey = this.bingKey;

            #endregion
            #region 어트리뷰트 그룹 공급자를 설정한다.

            AttributeGroupProvider attributeGroupProvider = new AttributeGroupProvider();

            attributeGroupProvider.AttributeName = "LocationName";

            #endregion
            #region 거리 기반 클러스터러를 설정한다.

            DistanceBasedClusterer distanceBasedClusterer = new DistanceBasedClusterer();

            distanceBasedClusterer.GroupProvider = attributeGroupProvider;

            #endregion
            #region 커스텀 클러스터 항목 팩토리를 설정한다.

            CustomClusterItemFactory customClusterItemFactory = new CustomClusterItemFactory();

            distanceBasedClusterer.SetClusterItemFactory(customClusterItemFactory);

            #endregion
            #region 트리 리스트를 설정한다.

            List<Tree> treeList = new List<Tree>();

            XDocument document = XDocument.Load("DATA\\TreesCl.xml");

            foreach(XElement element in document.Element("RowSet").Elements("Row"))
            {
                treeList.Add
                (
                    new Tree
                    {
                        Latitude     = Convert.ToDouble(element.Element("lat"     ).Value, CultureInfo.InvariantCulture),
                        Longitude    = Convert.ToDouble(element.Element("lon"     ).Value, CultureInfo.InvariantCulture),
                        LocationName =                  element.Element("location").Value.ToString(CultureInfo.InvariantCulture)
                    }
                );
            }

            #endregion
            #region 리스트 소스 데이터 어댑터를 설정한다.

            this.listSourceDataAdapter.DataSource = treeList;
            this.listSourceDataAdapter.Clusterer  = distanceBasedClusterer;

            #endregion
        }

        #endregion
    }
}